# Generated by Django 2.2.4 on 2019-08-21 13:07

import bitfield.models
from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field
import isc_common.fields.description_field
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0013_auto_20190821_1241'),
    ]

    operations = [
        migrations.CreateModel(
            name='Holidays_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('code', isc_common.fields.code_field.CodeField(blank=True, null=True)),
                ('name', isc_common.fields.name_field.NameField(blank=True, null=True)),
                ('description', isc_common.fields.description_field.DescriptionField()),
                ('begindate', models.DateTimeField(db_index=True, verbose_name='Начало')),
                ('enddate', models.DateTimeField(db_index=True, verbose_name='Конец')),
                ('type_day', models.CharField(max_length=255)),
                ('props', bitfield.models.BitField((('holiday', 'Праздник'), ('shorted', 'Сокращенный')), db_index=True, default=None)),
            ],
            options={
                'verbose_name': 'Праздничные дни',
                'db_table': 'clndr_holidays_view',
                'managed': False,
            },
        ),
    ]
